All platforms.

meme-lang.grammar

Meme language grammar spec.

Maps characters to scanlets — the complete syntactic specification of M-expression syntax as data. Lexlets provide the scanning layer, parselets provide the compound constructs, and the parser engine provides generic factories.

Meme language grammar spec.

Maps characters to scanlets — the complete syntactic specification
of M-expression syntax as data. Lexlets provide the scanning layer,
parselets provide the compound constructs, and the parser engine
provides generic factories.
raw docstring

grammarclj/s

Meme language grammar: characters → scanlets.

Meme language grammar: characters → scanlets.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries