meme-lang.lexlets

Meme lexical scanlets: character predicates, consume helpers, and trivia consumers.

This file provides the lexical layer for the meme language. The grammar spec in meme-grammar references these functions by name. Generic scanlet builders (atom-scanlet, single-char-scanlet, delimited-scanlet) live in meme.tools.lexer.

Meme lexical scanlets: character predicates, consume helpers,
and trivia consumers.

This file provides the lexical layer for the meme language. The grammar
spec in meme-grammar references these functions by name.
Generic scanlet builders (atom-scanlet, single-char-scanlet, delimited-scanlet)
live in meme.tools.lexer.
raw docstring

bom-consumerclj/s

(bom-consumer engine)

BOM consumer. Only matches at position 0. Returns nil if BOM is not at position 0, which causes skip-trivia! to stop (no match).

BOM consumer. Only matches at position 0. Returns nil if BOM is not
at position 0, which causes skip-trivia! to stop (no match).
sourceraw docstring

comment-consumerclj/s

(comment-consumer engine)
source

consume-char-literalclj/s

(consume-char-literal source len pos)
source

consume-keywordclj/s

(consume-keyword source len pos)
source

consume-numberclj/s

(consume-number source len pos)
source

consume-stringclj/s

(consume-string source len pos)
source

consume-symbolclj/s

(consume-symbol source len pos)
source

digit?clj/s

(digit? ch)
source

newline-char?clj/s

(newline-char? ch)
source

newline-consumerclj/s

(newline-consumer engine)
source

symbol-char?clj/s

(symbol-char? ch)
source

symbol-start?clj/s

(symbol-start? ch)
source

whitespace-char?clj/s

(whitespace-char? ch)
source

ws-consumerclj/s

(ws-consumer engine)
source

cljdoc builds & hosts documentation for Clojure/Script libraries