meme-lang.parselets

Meme-specific parselets for the Pratt parser.

Contains the compound parselets that handle meme's unique constructs: call adjacency detection, dispatch (#) sub-routing, tilde (~/@), and the M-expression call rule.

Meme-specific parselets for the Pratt parser.

Contains the compound parselets that handle meme's unique constructs:
call adjacency detection, dispatch (#) sub-routing, tilde (~/@),
and the M-expression call rule.
raw docstring

adjacent?clj/s

(adjacent? engine)

Call predicate: ( is a call only when no trivia was accumulated since the last expression ended. Checks the engine's trivia accumulator.

Call predicate: ( is a call only when no trivia was accumulated since
the last expression ended. Checks the engine's trivia accumulator.
sourceraw docstring

call-scanletclj/s

(call-scanlet engine lhs open-tok)

Led call scanlet — the M-expression rule. Receives engine, lhs, and open-tok.

Led call scanlet — the M-expression rule. Receives engine, lhs, and open-tok.
sourceraw docstring

dispatch-scanletclj/s

(dispatch-scanlet engine)
# dispatch scanlet. Peeks at the next character and sub-dispatches.
sourceraw docstring

reader-cond-extraclj/s

(reader-cond-extra tok)

Extract :splicing? from a reader-cond token (#? vs #?@).

Extract :splicing? from a reader-cond token (#? vs #?@).
sourceraw docstring

sign-followed-by-digit?clj/s

(sign-followed-by-digit? engine ch)

True if ch is + or - and the next char in engine is a digit.

True if ch is + or - and the next char in engine is a digit.
sourceraw docstring

tilde-scanletclj/s

(tilde-scanlet engine)

~ or ~@ scanlet.

~ or ~@ scanlet.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries