meme-lang.values

Shared value → string serialization for the printer and rewrite emitter. Handles atomic Clojure values (strings, numbers, chars, regex, etc.) that both emit paths must render identically.

Shared value → string serialization for the printer and rewrite emitter.
Handles atomic Clojure values (strings, numbers, chars, regex, etc.)
that both emit paths must render identically.
raw docstring

emit-char-strclj

(emit-char-str form)

Serialize a character to its reader representation: \newline, \a, etc.

Serialize a character to its reader representation: \newline, \a, etc.
sourceraw docstring

emit-number-strclj/s

(emit-number-str form)

Serialize a number, preserving BigDecimal M, BigInt N, and symbolic values.

Serialize a number, preserving BigDecimal M, BigInt N, and symbolic values.
sourceraw docstring

emit-regex-strclj/s

(emit-regex-str form)

Serialize a regex pattern to its source representation: #"pattern".

Serialize a regex pattern to its source representation: #"pattern".
sourceraw docstring

emit-value-strclj/s

(emit-value-str form emit-child-fn)

Serialize an atomic value to its string representation. Returns the string, or nil if the form is not an atomic value (i.e. the caller should handle it with its own dispatch). emit-child-fn is called for recursive cases (tagged literal data).

Serialize an atomic value to its string representation.
Returns the string, or nil if the form is not an atomic value
(i.e. the caller should handle it with its own dispatch).
emit-child-fn is called for recursive cases (tagged literal data).
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries