Meme lexical scanlets: character predicates, consume helpers, and trivia consumers.
This file provides the lexical layer for the meme language. The grammar spec in meme-grammar references these functions by name. Generic scanlet builders (atom-scanlet, single-char-scanlet, delimited-scanlet) live in meme.tools.lexer.
Meme lexical scanlets: character predicates, consume helpers, and trivia consumers. This file provides the lexical layer for the meme language. The grammar spec in meme-grammar references these functions by name. Generic scanlet builders (atom-scanlet, single-char-scanlet, delimited-scanlet) live in meme.tools.lexer.
(bom-consumer engine)BOM consumer. Only matches at position 0. Returns nil if BOM is not at position 0, which causes skip-trivia! to stop (no match).
BOM consumer. Only matches at position 0. Returns nil if BOM is not at position 0, which causes skip-trivia! to stop (no match).
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |