meme-lang.run

Meme-specific eval pipeline. Wires meme stages, syntax-quote resolution, and BOM stripping into the generic run infrastructure. JVM/Babashka only.

Meme-specific eval pipeline. Wires meme stages, syntax-quote resolution,
and BOM stripping into the generic run infrastructure.
JVM/Babashka only.
raw docstring

default-resolve-symbolclj

(default-resolve-symbol sym)

Resolve a symbol for syntax-quote, matching Clojure's SyntaxQuoteReader.

Resolve a symbol for syntax-quote, matching Clojure's SyntaxQuoteReader.
sourceraw docstring

run-fileclj

(run-file path)
(run-file path eval-fn-or-opts)

Read and eval a meme file. Returns the last result.

Read and eval a meme file. Returns the last result.
sourceraw docstring

run-stringclj

(run-string s)
(run-string s eval-fn-or-opts)

Read meme source string, eval each form, return the last result.

Read meme source string, eval each form, return the last result.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries