meme.cli

Unified CLI. Commands dispatch through lang maps.

Unified CLI. Commands dispatch through lang maps.
raw docstring

-mainclj

(-main & args)

CLI entry point. Parses args and dispatches to subcommands.

CLI entry point. Parses args and dispatches to subcommands.
sourceraw docstring

format-filesclj

(format-files opts)

Format meme source files in canonical style.

Format meme source files in canonical style.
sourceraw docstring

helpclj

(help _)

Print CLI usage help.

Print CLI usage help.
sourceraw docstring

inspect-langclj

(inspect-lang {:keys [lang]})

Print diagnostic info about the current lang configuration.

Print diagnostic info about the current lang configuration.
sourceraw docstring

replclj

(repl {:keys [lang] :as opts})

Start an interactive meme REPL.

Start an interactive meme REPL.
sourceraw docstring

runclj

(run {:keys [file lang rest-args] :as opts})

Run a meme source file. Requires :file in opts. Binds command-line-args to the user's args (excluding the command verb and filename).

Run a meme source file. Requires :file in opts.
Binds *command-line-args* to the user's args (excluding the command verb and filename).
sourceraw docstring

to-cljclj

(to-clj opts)

Convert meme files to Clojure and print to stdout or write to .clj files.

Convert meme files to Clojure and print to stdout or write to .clj files.
sourceraw docstring

to-memeclj

(to-meme opts)

Convert Clojure files to meme and print to stdout or write to .meme files.

Convert Clojure files to meme and print to stdout or write to .meme files.
sourceraw docstring

versionclj

(version _)

Print the meme version.

Print the meme version.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries