Unified CLI. Commands dispatch through lang maps.
Unified CLI. Commands dispatch through lang maps.
(-main & args)CLI entry point. Parses args and dispatches to subcommands.
CLI entry point. Parses args and dispatches to subcommands.
(format-files opts)Format meme source files in canonical style.
Format meme source files in canonical style.
(inspect-lang {:keys [lang]})Print diagnostic info about the current lang configuration.
Print diagnostic info about the current lang configuration.
(repl {:keys [lang] :as opts})Start an interactive meme REPL.
Start an interactive meme REPL.
(run {:keys [file lang rest-args] :as opts})Run a meme source file. Requires :file in opts. Binds command-line-args to the user's args (excluding the command verb and filename).
Run a meme source file. Requires :file in opts. Binds *command-line-args* to the user's args (excluding the command verb and filename).
(to-clj opts)Convert meme files to Clojure and print to stdout or write to .clj files.
Convert meme files to Clojure and print to stdout or write to .clj files.
(to-meme opts)Convert Clojure files to meme and print to stdout or write to .meme files.
Convert Clojure files to meme and print to stdout or write to .meme files.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |